@@ -41,7 +41,8 @@ def walk(value: str, docs_dir: str, config_dir) -> list:
     _, api_path, *tops = value.split("/")
     abs_api_path = os.path.join(docs_dir, api_path)
     if os.path.exists(abs_api_path):
-        logger.error(f'[MkApi] {abs_api_path} exists: Delete manually for safety.')
+        logger.error(f"[MkApi] {abs_api_path} exists: Delete manually for safety.")
+        sys.exit(1)
     os.mkdir(abs_api_path)
     atexit.register(lambda path=abs_api_path: rmtree(path))
 
@@ -54,23 +55,31 @@ def walk(value: str, docs_dir: str, config_dir) -> list:
     for paths in _walk(top):
         package = os.path.relpath(paths[0], root)
         package = package.replace("/", ".").replace("\\", ".")
-        pages = []
         package_obj = importlib.import_module(package)
         if inspect.getdoc(package_obj):
             paths[0] = ""
         else:
             paths = paths[1:]
 
+        pages = []
         for path in paths:
             if path:
                 module = ".".join([package, path])
+                module_obj = importlib.import_module(module)
+                if not inspect.getdoc(module_obj):
+                    continue
             else:
                 module = package
             abs_path = "/".join([abs_api_path, module]) + ".md"
-            create_page(abs_path, module)
+            if path == "":
+                children = paths[1:]
+            else:
+                children = []
+            create_page(abs_path, module, children)
             page = os.path.relpath(abs_path, docs_dir).replace("\\", "/")
-            pages.append(page)
-        nav.append({package: pages})
+            pages.append({page[:-3].split(".")[-1]: page})
+        if pages:
+            nav.append({package: pages})
 
     return nav
 
@@ -84,13 +93,13 @@ def rmtree(path):
         logger.warning(f"[MkApi] Couldn't delete directory: {path}")
 
 
-def create_page(abs_path, module: str):
+def create_page(abs_path, module: str, children: List[str]):
     with open(abs_path, "w") as f:
-        f.write(create_markdown(module))
+        f.write(create_markdown(module, children))
 
 
-def create_markdown(module: str) -> str:
+def create_markdown(module: str, children: List[str]) -> str:
     node = get_node(module, max_depth=1)
     members = [member.id for member in node.members]
-    markdown = renderer.render_page(node, module, members)
+    markdown = renderer.render_page(node, module, members, children)
     return markdown
